"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const node_cache_1 = tslib_1.__importDefault(require("node-cache"));
const axios_1 = tslib_1.__importDefault(require("axios"));
class StaticContentLoader {
    constructor(baseUrl, options) {
        this.baseUrl = baseUrl;
        this.options = options;
        this.defaultIndexFileName = 'index.json';
        this.defaultTimeout = 3000;
        this.cache = new node_cache_1.default({ stdTTL: 3600, checkperiod: 120 });
        this.fetchIndex = () => tslib_1.__awaiter(this, void 0, void 0, function* () {
            const cacheIndex = this.cache.get('INDEX');
            if (cacheIndex)
                return cacheIndex;
            const { data: index } = yield this.axios.get((this.options && this.options.indexFileName) || this.defaultIndexFileName);
            if (!index)
                throw new Error('Failed to load default index');
            this.cache.set('INDEX', index);
            return index;
        });
        this.fetchContent = (contentPath) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            let cacheContent = this.cache.get(`#${contentPath}#`);
            if (cacheContent)
                return cacheContent;
            const { data: content } = yield this.axios.get(contentPath);
            this.cache.set(`${contentPath}`, content);
            return content;
        });
        this.axios = axios_1.default.create({
            baseURL: baseUrl,
            timeout: (options && options.timeout) || this.defaultTimeout
        });
    }
}
exports.default = StaticContentLoader;
//# sourceMappingURL=index.js.map